# Generated by roxygen2: do not edit by hand

export(cdr)
export(cdr_antarctic_daily)
export(cdr_antarctic_monthly)
export(cdr_arctic_daily)
export(cdr_arctic_monthly)
export(cdr_fix)
export(cdr_fix_grid)
export(cdr_fix_names)
export(sea_ice_index)
