% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cdr.R
\name{cdr}
\alias{cdr}
\title{Download sea ice concentration from NSIDC Climate Data Record}
\usage{
cdr(
  date_range = c(NA, NA),
  variables = "aice",
  hemisphere = c("south", "north"),
  resolution = c("monthly", "daily"),
  date_stride = 1,
  xgrid_range = c(NA, NA),
  xgrid_stride = 1,
  ygrid_range = c(NA, NA),
  ygrid_stride = 1,
  version = 6,
  format = "nc",
  file = NULL,
  dir = tempdir(),
  use_cache = TRUE
)
}
\arguments{
\item{date_range}{Vector of size two with the start and end dates. Supported
formats are:
\itemize{
\item A Date or POSIXct/POSIXlt object.
\item A character vector with ISO format dates: \code{c("2020-01-01", "2020-12-31")}
\item A character vector with year-month: \code{c("2020-01", "2020-06")} (expands to first/last day of month).
\item A character vector with year only: \code{c("2020", "2021")} (expands to full year).
}}

\item{variables}{Character vector with the variables to fetch. Valid values are
\describe{\item{\code{aice}}{CDR Sea ice concentration.}
\item{\code{qa}}{Quality control flag.}
\item{\code{stdev}}{Sea ice standard deviation.}
\item{\code{interpolation_spatial}}{Flag for spatial interpolation.}
\item{\code{interpolation_temporal}}{Flag for temporal interpolation.}
\item{\code{aice_bt}}{Sea ice concentration of the Bootstrap method.}
\item{\code{aice_nt}}{Sea ice concentration of the Nasa Team method.}}
Although not all variables are available in all versions and all resolutions.
The \verb{*_nt} and \verb{*_bt} variables are only available in version 4 and the
interpolation flags are only available for daily values.}

\item{hemisphere}{Character with the hemisphere to download.
Can be either "south" or "north".}

\item{resolution}{Character with the temporal resolution.
Can be either "monthly" or "daily".}

\item{date_stride}{Numeric with the temporal stride.
A number greater than 1 means to take only the nth date in the series.}

\item{xgrid_range}{Numeric vector of size 2 with the range of the x dimension.}

\item{xgrid_stride}{Numeric with the stride of the x dimension.}

\item{ygrid_range}{Numeric vector of size 2 with the range of the y dimension.}

\item{ygrid_stride}{Numeric with the stride of the y dimension.}

\item{version}{Version of the dataset. Can be 4 or 5.}

\item{format}{Character with the format.}

\item{file}{Character with the file name to use for download. If \code{NULL},
the file name will be constructed by hashing the request URL.
Requests consisting in more than one file will append a number.}

\item{dir}{Directory where to download the file.}

\item{use_cache}{Logical indicating whether to not perform the download if
the file already exist.}
}
\value{
Path or vector of paths to the downloaded files.
}
\description{
This is a low-level function to download data from PolarWatch's ERDDAP
server.
}
\examples{
\dontrun{
cdr(date_range = c("2022-01", "2022-01"),
    # Data every 7 days
    date_stride = 7,
    resolution = "daily",
    # Thin the grid by taking every other gridpoint
    xgrid_stride = 2,
    ygrid_stride = 2,
    hemisphere = "north"
    )
}
}
