% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sea_ice_index.R
\name{sea_ice_index}
\alias{sea_ice_index}
\title{Download sea ice index data.}
\usage{
sea_ice_index(
  hemisphere = c("south", "north"),
  resolution = c("monthly", "daily"),
  file = NULL,
  dir = tempdir(),
  use_cache = TRUE
)
}
\arguments{
\item{hemisphere}{Character with the hemisphere to download.
Can be either "south" or "north".}

\item{resolution}{Character with the temporal resolution.
Can be either "monthly" or "daily".}

\item{file}{Character with the file name to use for download. If \code{NULL},
the file name will be constructed by hashing the request URL.
Requests consisting in more than one file will append a number.}

\item{dir}{Directory where to download the file.}

\item{use_cache}{Logical indicating whether to not perform the download if
the file already exist.}
}
\value{
The route to the file name.
}
\description{
The NSIDC sea ice index product provides computed sea ice extent for each hemisphere
on daily and monthly resolution.
}
\details{
The returned files are not the raw files, but contain minor format modifications
for ease of use. Instead of \code{year} and \code{month} columns, there is a single \code{time}
column.
Instead of a \code{region} column with \code{"S"} or \code{"N"} values, there is a \code{hemisphere}
column with values \code{"south"} and \code{"north"} (for consistency with the function
arguments).
Column names are all in lower case and are the same for the daily and monthly
products, except for an \code{area} column that is only available in the monthly product.
Area and extent values are expressed in km^2.
}
\examples{
\dontrun{
sea_ice_index("south", "monthly")
}

}
