% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/icecdr-package.R
\docType{package}
\name{icecdr-package}
\alias{icecdr}
\alias{icecdr-package}
\title{icecdr: Download Sea Ice Concentration Data from the NSIDC Climate Data Record}
\description{
Programmatic access to NSIDC's sea ice concentration CDR \url{https://nsidc.org/data/g02202} via ERDAPP server and Sea Ice index \url{https://nsidc.org/data/g02135}. Supports caching results and optional fixes for some inconsistencies of the raw files.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://github.com/eliocamp/icecdr}
  \item \url{https://eliocamp.github.io/icecdr/}
  \item Report bugs at \url{https://github.com/eliocamp/icecdr/issues}
}

}
\author{
\strong{Maintainer}: Elio Campitelli \email{eliocampitelli@gmail.com} (\href{https://orcid.org/0000-0002-7742-9230}{ORCID}) [copyright holder]

Authors:
\itemize{
  \item Elio Campitelli \email{eliocampitelli@gmail.com} (\href{https://orcid.org/0000-0002-7742-9230}{ORCID}) [copyright holder]
}

}
\keyword{internal}
