% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cdr.R
\name{cdr_antarctic_monthly}
\alias{cdr_antarctic_monthly}
\alias{cdr_antarctic_daily}
\alias{cdr_arctic_monthly}
\alias{cdr_arctic_daily}
\title{Convenience functions}
\usage{
cdr_antarctic_monthly(
  date_range,
  variables = "aice",
  version = 6,
  file = NULL,
  dir = tempdir(),
  use_cache = TRUE
)

cdr_antarctic_daily(
  date_range,
  variables = "aice",
  version = 6,
  file = NULL,
  dir = tempdir(),
  use_cache = TRUE
)

cdr_arctic_monthly(
  date_range,
  variables = "aice",
  version = 6,
  file = NULL,
  dir = tempdir(),
  use_cache = TRUE
)

cdr_arctic_daily(
  date_range,
  variables = "aice",
  version = 6,
  file = NULL,
  dir = tempdir(),
  use_cache = TRUE
)
}
\arguments{
\item{date_range}{Vector of size two with the start and end dates. Supported
formats are:
\itemize{
\item A Date or POSIXct/POSIXlt object.
\item A character vector with ISO format dates: \code{c("2020-01-01", "2020-12-31")}
\item A character vector with year-month: \code{c("2020-01", "2020-06")} (expands to first/last day of month).
\item A character vector with year only: \code{c("2020", "2021")} (expands to full year).
}}

\item{variables}{Character vector with the variables to fetch. Valid values are
\describe{\item{\code{aice}}{CDR Sea ice concentration.}
\item{\code{qa}}{Quality control flag.}
\item{\code{stdev}}{Sea ice standard deviation.}
\item{\code{interpolation_spatial}}{Flag for spatial interpolation.}
\item{\code{interpolation_temporal}}{Flag for temporal interpolation.}
\item{\code{aice_bt}}{Sea ice concentration of the Bootstrap method.}
\item{\code{aice_nt}}{Sea ice concentration of the Nasa Team method.}}
Although not all variables are available in all versions and all resolutions.
The \verb{*_nt} and \verb{*_bt} variables are only available in version 4 and the
interpolation flags are only available for daily values.}

\item{version}{Version of the dataset. Can be 4 or 5.}

\item{file}{Character with the file name to use for download. If \code{NULL},
the file name will be constructed by hashing the request URL.
Requests consisting in more than one file will append a number.}

\item{dir}{Directory where to download the file.}

\item{use_cache}{Logical indicating whether to not perform the download if
the file already exist.}
}
\value{
A string vector with the location of the downloaded files
}
\description{
These are convenience functions to download, daily or monthly
sea ice concentration data from the whole Antarctic or Arctic.
For a more complete low level function, see \code{\link[=cdr]{cdr()}}.
}
\examples{
\dontrun{
cdr_antarctic_monthly(c("2022-01", "2022-01"))
}


}
